searchData={"items":[{"type":"module","title":"Handle.Domain","doc":"Provides functionality to parse and extract domain components from a given hostname\nusing a list of public and test suffix rules.","ref":"Handle.Domain.html"},{"type":"module","title":"Overview - Handle.Domain","doc":"This module loads public suffix rules from a local file (`priv/public_suffix_list.dat`)\nand combines them with predefined test domains. It offers a `parse/1` function\nthat takes a hostname and returns a structured representation of the domain components\n(domain, subdomain, TLD, and type) or an error if the domain is invalid.","ref":"Handle.Domain.html#module-overview"},{"type":"module","title":"Parsing a Hostname - Handle.Domain","doc":"- The `parse/1` function takes a hostname as a string.\n- If a matching rule is found, it builds a domain component struct using `Components.build/2`.\n- If no rule matches, it returns an error tuple indicating an invalid domain.","ref":"Handle.Domain.html#module-parsing-a-hostname"},{"type":"module","title":"Example - Handle.Domain","doc":"iex> Handle.Domain.parse(\"sub.example.co.uk\")\n    {:ok, %Handle.Domain.Components{\n      domain: \"example\",\n      subdomain: \"sub\",\n      tld: \"co.uk\",\n      type: :public\n    }}","ref":"Handle.Domain.html#module-example"},{"type":"function","title":"Handle.Domain.parse/1","doc":"Parses a given hostname and returns a structured representation of its domain components.\n\nIf the hostname matches a public suffix rule, the function returns a domain component struct.\nIf no rule matches, it returns an error tuple with a message indicating an invalid domain.","ref":"Handle.Domain.html#parse/1"},{"type":"function","title":"Example - Handle.Domain.parse/1","doc":"iex> Handle.Domain.parse(\"sub.example.co.uk\")\n    {:ok, %Handle.Domain.Components{\n      domain: \"example\",\n      subdomain: \"sub\",\n      tld: \"co.uk\",\n      type: :public\n    }}\n\n    iex> Handle.Domain.parse(\"sub.example.not_a_tld\")\n    {:error, \"Invalid domain\"}","ref":"Handle.Domain.html#parse/1-example"},{"type":"function","title":"localhost - Handle.Domain.parse/1","doc":"The function recognizes `localhost` as a special case and returns a domain component struct\nwith an empty TLD and the type set to `:test`.\n\n    iex> Handle.Domain.parse(\"sub.localhost\")\n    {:ok, %Handle.Domain.Components{\n      domain: \"localhost\",\n      subdomain: \"sub\",\n      tld: \"\",\n      type: :test\n    }}","ref":"Handle.Domain.html#parse/1-localhost"},{"type":"function","title":"Test Domains - Handle.Domain.parse/1","doc":"The function recognizes predefined test domains that are not strictly valid TLDs.\n\nExamples include:\n\n  - `.example`\n  - `.invalid`\n  - `.test`\n  - `.local`","ref":"Handle.Domain.html#parse/1-test-domains"},{"type":"module","title":"Handle.Domain.Components","doc":"Provides functionality to build a structured domain representation from parsed rules and domain parts.\n\nThe module defines a struct for a domain, including:\n  - `:domain` – the main domain name\n  - `:subdomain` – any subdomain portions\n  - `:tld` – top-level domain portion\n  - `:type` – domain type (`:public`, `:private`, or `:test`)","ref":"Handle.Domain.Components.html"},{"type":"module","title":"Building Domains - Handle.Domain.Components","doc":"The primary function `build/2` takes a parsed rule (`Handle.Domain.Rule.t()`) and a list of domain parts,\nthen attempts to construct a `%Handle.Domain.Components{}` struct based on the rule type.\n\n- For wildcard rules (`:wildcard`), it splits the domain parts to extract the TLD, domain, and subdomain.\n- For other rule types, it handles the special case where the domain is \"localhost\"\n  (treated as a test domain without a TLD), and standard domain parsing for other cases.\n\nIf the domain parts do not meet expectations (e.g., top-level domain only),\nit returns an error tuple with an appropriate message.","ref":"Handle.Domain.Components.html#module-building-domains"},{"type":"module","title":"Examples - Handle.Domain.Components","doc":"iex> rule = %Handle.Domain.Rule{rule_type: :standard, length: 1, parts: [\"com\"], domain_type: :public}\n    iex> Handle.Domain.Components.build(rule, [\"com\", \"example\", \"sub\"])\n    {:ok, %Handle.Domain.Components{\n       domain: \"example\",\n       subdomain: \"sub\",\n       tld: \"com\",\n       type: :public\n     }}","ref":"Handle.Domain.Components.html#module-examples"},{"type":"function","title":"Handle.Domain.Components.build/2","doc":"","ref":"Handle.Domain.Components.html#build/2"},{"type":"type","title":"Handle.Domain.Components.t/0","doc":"","ref":"Handle.Domain.Components.html#t:t/0"},{"type":"module","title":"Handle.Domain.Rule","doc":"Provides functionality for parsing and matching domain rules defined by the\nPublic Suffix List and as described at\nhttps://github.com/publicsuffix/list/wiki/Format#format\n\nThis module defines a struct representing a domain rule with its type, length, parts,\nand associated domain type (public, private, or test). It provides functions to parse\nstring representations of rules and to match domain parts against these rules.","ref":"Handle.Domain.Rule.html"},{"type":"module","title":"Parsing Rules - Handle.Domain.Rule","doc":"The `parse/2` function processes a string rule and a domain type to produce a rule struct or special values:\n  - Returns `nil` for empty or comment lines.\n  - Returns `:begin_private_domains` for the specific marker line.\n  - Parses rules starting with `\"!\"` as exceptions.\n  - Parses rules starting with `\"*.\"` as wildcards.\n  - All other rules are parsed as standard.","ref":"Handle.Domain.Rule.html#module-parsing-rules"},{"type":"module","title":"Matching - Handle.Domain.Rule","doc":"The `match?/2` function checks if a given list of domain parts starts with the parts of the rule,\ndetermining if the rule matches the domain.","ref":"Handle.Domain.Rule.html#module-matching"},{"type":"module","title":"Examples - Handle.Domain.Rule","doc":"iex> rule = Handle.Domain.Rule.parse(\"*.example.com\", :public)\n    iex> Handle.Domain.Rule.match?(rule, [\"com\", \"example\", \"subdomain\"])\n    true","ref":"Handle.Domain.Rule.html#module-examples"},{"type":"type","title":"Handle.Domain.Rule.domain_type/0","doc":"","ref":"Handle.Domain.Rule.html#t:domain_type/0"},{"type":"function","title":"Handle.Domain.Rule.match?/2","doc":"Checks if a given list of domain parts matches the rule.","ref":"Handle.Domain.Rule.html#match?/2"},{"type":"function","title":"Examples - Handle.Domain.Rule.match?/2","doc":"iex> rule = Handle.Domain.Rule.parse(\"*.example.com\", :public)\n    iex> Handle.Domain.Rule.match?(rule, [\"com\", \"example\", \"subdomain\"])\n    true\n    iex> Handle.Domain.Rule.match?(rule, [\"org\", \"example\", \"subdomain\"])\n    false","ref":"Handle.Domain.Rule.html#match?/2-examples"},{"type":"function","title":"Handle.Domain.Rule.parse/2","doc":"Parses a rule line defined in the Public Suffix List format and returns a rule struct.\n\nThe function takes a rule line and a domain type (:public, :private, or :test) and returns:\n  - `nil` for empty or comment lines.\n  - `:begin_private_domains` for the specific marker line when transitioning\n    to the private domain list.\n  - A rule struct for standard, wildcard, or exception rules.","ref":"Handle.Domain.Rule.html#parse/2"},{"type":"type","title":"Handle.Domain.Rule.t/0","doc":"","ref":"Handle.Domain.Rule.html#t:t/0"},{"type":"task","title":"mix compile.rule_downloader","doc":"Downloads the latest public suffix list rules.","ref":"Mix.Tasks.Compile.RuleDownloader.html"},{"type":"extras","title":"Handle.Domain","doc":"# Handle.Domain\n\n**Handle.Domain** is an Elixir library for parsing hostnames and extracting\ntheir domain components—such as domain, subdomain, TLD, and type—based on\npublic and test suffix rules. It leverages the Public Suffix List to accurately\nidentify domain parts for various domain types.\n\nThe Public Suffix List is automatically updated daily to ensure that the\nlibrary's parsing rules are up-to-date. This allows for accurate domain\nparsing and classification, even for new TLDs and domain types.","ref":"readme.html"},{"type":"extras","title":"Features - Handle.Domain","doc":"- Parse hostnames to determine domain, subdomain, and TLD.\n- Distinguish between public, private, and test domains.\n- Use the Public Suffix List for up-to-date rule parsing.\n- Handle wildcard and exception rules effectively.","ref":"readme.html#features"},{"type":"extras","title":"Installation - Handle.Domain","doc":"Add `handle_domain` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:handle_domain, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Handle.Domain","doc":"To parse a hostname and obtain its components:\n\n```elixir\ncase Handle.Domain.parse(\"sub.example.co.uk\") do\n  {:ok, domain_info} ->\n    # domain_info is a %Handle.Domain.Components{} struct containing:\n    # - domain: \"example\"\n    # - subdomain: \"sub\"\n    # - tld: \"co.uk\"\n    # - type: :public\n\n    IO.inspect(domain_info)\n\n  {:error, reason} ->\n    IO.puts(\"Error: #{reason}\")\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Contributing - Handle.Domain","doc":"Contributions are welcome! Please open issues or submit pull requests for\nimprovements or bug fixes.","ref":"readme.html#contributing"},{"type":"extras","title":"License - Handle.Domain","doc":"This project is licensed under the MIT License. See the [LICENSE](LICENSE) file\nfor details.","ref":"readme.html#license"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2025 Mark Glenn\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}